==> apex-api-3.2.0-incubating-sources.jar: com/datatorrent/api/annotation/ApplicationAnnotation.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.datatorrent.api.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;


/**
 * Annotation to specify characteristics of an application.<p>
 *
 * @since 1.0.1
 */
@Documented
@Target(ElementType.TYPE)
@Retention(RetentionPolicy.RUNTIME)
public @interface ApplicationAnnotation {
  
  /**
   * <p>Compile time application alias.</p> 
   * <p>There are 3 ways to specify application name</p>
   * <li>Compile time application alias -- specified in annotation</li>
   * <li>Configuration time application alias -- specified in dt-site.xml</li>
   * <li>Runtime application alias -- specified in application code</li>
   * 
   */
  public String name();
  
}

==> apex-api-3.3.0-incubating-sources.jar: com/datatorrent/api/annotation/ApplicationAnnotation.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.datatorrent.api.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;


/**
 * Annotation to specify characteristics of an application.<p>
 *
 * @since 1.0.1
 */
@Documented
@Target(ElementType.TYPE)
@Retention(RetentionPolicy.RUNTIME)
public @interface ApplicationAnnotation
{
  
  /**
   * <p>Compile time application alias.</p> 
   * <p>There are 3 ways to specify application name</p>
   * <li>Compile time application alias -- specified in annotation</li>
   * <li>Configuration time application alias -- specified in dt-site.xml</li>
   * <li>Runtime application alias -- specified in application code</li>
   * 
   */
  public String name();
  
}
